==> kst-0.98.tar.gz: kst-0.98/kst/kst/kstviewfitsdialog_i.h <==
/***************************************************************************
                       kstviewfitsdialog_i.h  -  Part of KST
                             -------------------
    begin                :
    copyright            : (C) 2004 The University of British Columbia
    email                :
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KSTVIEWFITSDIALOGI_H
#define KSTVIEWFITSDIALOGI_H

#include "viewfitsdialog.h"
#include "kstfittable.h"

class KstViewFitsDialogI : public KstViewFitsDialog {
  Q_OBJECT
  public:
    KstViewFitsDialogI(QWidget* parent = 0,
                        const char* name = 0,
                        bool modal = FALSE, WFlags fl = 0 );
    virtual ~KstViewFitsDialogI();
    KstFitTable* tableFits;
    
  public slots:
    void updateViewFitsDialog();
    void showViewFitsDialog();
    void showViewFitsDialog(const QString& strVector);
    void updateDefaults(int index=0);

  protected slots:
    virtual void fitChanged(const QString& strFit);
  
  private slots:
    
  signals:

  private:
    void fillComboBox( const QString& str );
};


#endif // KSTVIEWFITSDIALOGI_H

==> kst_1.0.0.orig.tar.gz: kst-1.0.0/kst/kst/kstviewfitsdialog_i.h <==
/***************************************************************************
                       kstviewfitsdialog_i.h  -  Part of KST
                             -------------------
    begin                :
    copyright            : (C) 2004 The University of British Columbia
    email                :
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KSTVIEWFITSDIALOGI_H
#define KSTVIEWFITSDIALOGI_H

#include "viewfitsdialog.h"
#include "kstfittable.h"

class KstViewFitsDialogI : public KstViewFitsDialog {
  Q_OBJECT
  public:
    KstViewFitsDialogI(QWidget* parent = 0,
                        const char* name = 0,
                        bool modal = false, WFlags fl = 0 );
    virtual ~KstViewFitsDialogI();
    KstFitTable* tableFits;
    
  public slots:
    void updateViewFitsDialog();
    void showViewFitsDialog();
    void showViewFitsDialog(const QString& strVector);
    void updateDefaults(int index = 0);

  protected slots:
    virtual void fitChanged(const QString& strFit);

  private:
    void fillComboBox(const QString& str);
};


#endif // KSTVIEWFITSDIALOGI_H
